@@ -1,3 +1,3 @@
-from amqpqueue import Producer, Consumer, Error
+from amqpqueue import Producer, Consumer, Subscriber, Error
 from queuefactory import QueueFactory
 from worker import Worker, WorkerFactory, ShellWorker, ShellFileWorker, HTTPWorker
