@@ -8,9 +8,9 @@ from amqpqueue import Producer, Consumer
 FORMAT_CONS = '%(asctime)s %(name)-12s %(levelname)8s\t%(message)s'
 logging.basicConfig(level=logging.DEBUG, format=FORMAT_CONS)
 
-qp = Producer('test_q', addr='registry.ouls.ox.ac.uk:5672', userid='userid', password='password')
+qp = Producer('test_q', addr='localhost:5672', userid='guest', password='guest')
 qp.put('test')
-qc = Consumer('test_q', addr='registry.ouls.ox.ac.uk:5672', userid='userid', password='password')
+qc = Consumer('test_q', addr='localhost:5672', userid='guest', password='guest')
 print qc.get()
 qc.task_done()
 
